# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_240_FieldWidthPosName_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_240)

  def run_test_240(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from sales")
    result2 = DbtPy.exec_immediate(conn, "select * from staff")
    result3 = DbtPy.exec_immediate(conn, "select * from emp_photo")
    
    for i in range(0, DbtPy.num_fields(result)):
      print(str(i) + ":" + str(DbtPy.field_width(result,i)))
    
    print("\n-----")
    
    for i in range(0, DbtPy.num_fields(result2)):
      print(str(i) + ":" + str(DbtPy.field_width(result2,DbtPy.field_name(result2,i))))
          
    print("\n-----")
    
    for i in range(0, 3):
      print(str(i) + ":" + str(DbtPy.field_width(result3,i)) + "," + str(DbtPy.field_display_size(result3,i)))
    
    print("\n-----")
    print("region:%s" % DbtPy.field_type(result,'region'))
    
    print("5:%s" % DbtPy.field_type(result2,5))

#__END__
#__LUW_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__ZOS_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__SYSTEMI_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__IDS_EXPECTED__
#0:6
#1:15
#2:15
#3:4
#
#-----
#0:2
#1:9
#2:2
#3:5
#4:2
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:2147483647,2147483647
#
#-----
#region:string
#5:decimal



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_157a_FetchAssocWithoutScrollableCursorErr(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_157a)

  def run_test_157a(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    print("Starting...")
    if conn:
      sql = "SELECT id, name, breed, weight FROM animals ORDER BY breed"
      result = DbtPy.exec_immediate(conn, sql)

      try:
          i = 2
          row = DbtPy.fetch_assoc(result, i)
          while ( row ):
              if (server.DBMS_NAME[0:3] == 'Inf'):
                print("%-5d %-16s %-32s %10s" % (row['id'], row['name'], row['breed'], row['weight']))
              else:
                print("%-5d %-16s %-32s %10s" % (row['ID'], row['NAME'], row['BREED'], row['WEIGHT']))
              i = i + 2
          row = DbtPy.fetch_assoc(result, i)
      except:
          print("SQLSTATE: %s" % DbtPy.stmt_error(result))
          print("Message: %s" % DbtPy.stmt_errormsg(result))
	
      print("DONE")

#__END__
#__LUW_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE
#__ZOS_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE
#__SYSTEMI_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE
#__IDS_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [GBasedbt][GBase ODBC Driver]Fetch type out of range. SQLCODE=-11086
#DONE




# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_241_FieldWidthPosName_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_241)

  def run_test_241(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from sales")
    result2 = DbtPy.exec_immediate(conn, "select * from staff")
    result3 = DbtPy.exec_immediate(conn, "select * from emp_photo")
    
    for i in range(0, DbtPy.num_fields(result)):
      print(str(DbtPy.field_width(result,i)))
    
    print("\n-----")
    
    for i in range(0, DbtPy.num_fields(result2)):
      print(str(DbtPy.field_width(result2,DbtPy.field_name(result2,i))))

#__END__
#__LUW_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9
#__ZOS_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9
#__SYSTEMI_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9
#__IDS_EXPECTED__
#6
#15
#15
#4
#
#-----
#2
#9
#2
#5
#2
#9
#9



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_039_FetchRowIndexPosNested_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_039)

  def run_test_039(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    serverinfo = DbtPy.server_info( conn )

    if (serverinfo.DBMS_NAME[0:3] != 'Inf'):
      result = DbtPy.prepare(conn, "SELECT * FROM animals", {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_KEYSET_DRIVEN})
    else:
      result = DbtPy.prepare(conn, "SELECT * FROM animals")
    DbtPy.execute(result)
    row = DbtPy.fetch_row(result)
    while ( row ):
      if (serverinfo.DBMS_NAME[0:3] != 'Inf'):
        result2 = DbtPy.prepare(conn, "SELECT * FROM animals", {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_KEYSET_DRIVEN})
      else:
        result2 = DbtPy.prepare(conn, "SELECT * FROM animals")
      DbtPy.execute(result2)
      while (DbtPy.fetch_row(result2)):
        print("%s : %s : %s : %s" % (DbtPy.result(result2, 0), \
                                     DbtPy.result(result2, 1), \
                                     DbtPy.result(result2, 2), \
                                     DbtPy.result(result2, 3)))
      row = DbtPy.fetch_row(result)

#__END__
#__LUW_EXPECTED__
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#__ZOS_EXPECTED__
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#__SYSTEMI_EXPECTED__
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#__IDS_EXPECTED__
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00
#0 : cat : Pook             : 3.20
#1 : dog : Peaches          : 12.30
#2 : horse : Smarty           : 350.00
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#5 : goat : Rickety Ride     : 9.70
#6 : llama : Sweater          : 150.00



#

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_264_InsertRetrieveBIGINTTypeColumn(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_264)

  def run_test_264(self):
    # Make a connection
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    if conn:
       server = DbtPy.server_info( conn )
       if (server.DBMS_NAME[0:3] == 'Inf'):
          op = {DbtPy.ATTR_CASE: DbtPy.CASE_UPPER}
          DbtPy.set_option(conn, op, 1)

       # Drop the tab_bigint table, in case it exists
       drop = 'DROP TABLE tab_bigint'
       result = ''
       try:
         result = DbtPy.exec_immediate(conn, drop)
       except:
         pass
       # Create the tab_bigint table
       if (server.DBMS_NAME[0:3] == 'Inf'):
          create = "CREATE TABLE tab_bigint (col1 INT8, col2 INT8, col3 INT8, col4 INT8)"
       else:
          create = "CREATE TABLE tab_bigint (col1 BIGINT, col2 BIGINT, col3 BIGINT, col4 BIGINT)"
       result = DbtPy.exec_immediate(conn, create)

       insert = "INSERT INTO tab_bigint values (-9223372036854775807, 9223372036854775807, 0, NULL)"
       res = DbtPy.exec_immediate(conn, insert)
       print("Number of inserted rows:", DbtPy.num_rows(res))

       stmt = DbtPy.prepare(conn, "SELECT * FROM tab_bigint")
       DbtPy.execute(stmt)
       data = DbtPy.fetch_both(stmt)
       while ( data ):
         print(data[0])
         print(data[1])
         print(data[2])
         print(data[3])
         print(type(data[0]) is int)
         print(type(data[1]) is int) 
         print(type(data[2]) is int)
         data = DbtPy.fetch_both(stmt)

       # test DbtPy.result for fetch of bigint
       stmt1 = DbtPy.prepare(conn, "SELECT col2 FROM tab_bigint")
       DbtPy.execute(stmt1)
       DbtPy.fetch_row(stmt1, 0)
       if (server.DBMS_NAME[0:3] != 'Inf'):
         row1 = DbtPy.result(stmt1, 'COL2')
       else:
         row1 = DbtPy.result(stmt1, 'col2')
       print(row1)
       
       DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#9223372036854775807
#__ZOS_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#9223372036854775807
#__SYSTEMI_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#9223372036854775807
#__IDS_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#9223372036854775807



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_064_Tables_05(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_064)

  def run_test_064(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    result = DbtPy.tables(conn, None, 't')
    
    for i in range(0, DbtPy.num_fields(result)):
      print("%s, " % DbtPy.field_name(result, i))
    print()
    print()
  
    i = 0
    row = DbtPy.fetch_tuple(result)
    while ( row ):
      DbtPy.num_fields(result)
      if (i < 4):
        print(", " + row[1] + ", " + row[2] + ", " + row[3] + ", ,\n")
      i = i + 1
      row = DbtPy.fetch_tuple(result)

    DbtPy.free_result(result)

    DbtPy.exec_immediate(conn, 'DROP TABLE t.t1')
    DbtPy.exec_immediate(conn, 'DROP TABLE t.t2')
    DbtPy.exec_immediate(conn, 'DROP TABLE t.t3')
    DbtPy.exec_immediate(conn, 'DROP TABLE t.t4')

#__END__ 
#__IDS_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, t, t1, TABLE, ,
#, t, t2, TABLE, ,
#, t, t3, TABLE, ,
#, t, t4, TABLE, ,




import unittest, sys, datetime
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_InsertRetrieveDateTimeTypeColumn(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_InsertRetrieveDateTimeTypeColumn)

  def run_test_InsertRetrieveDateTimeTypeColumn(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      drop = 'DROP TABLE tab_datetime'
      result = ''
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass
      t_val = datetime.time(10, 42, 34)
      d_val = datetime.date(1981, 7, 8)
      #ts_val = datetime.datetime.today()
      ts_val = datetime.datetime(1981, 7, 8, 10, 42, 34, 10)
      server = DbtPy.server_info( conn )
      if (server.DBMS_NAME[0:3] == 'Inf'):
        statement = "CREATE TABLE tab_datetime (col1 DATETIME HOUR TO SECOND, col2 DATE, col3 DATETIME YEAR TO FRACTION(5))"
        result = DbtPy.exec_immediate(conn, statement)
        statement = "INSERT INTO tab_datetime (col1, col2, col3) values (?, ?, ?)"
        stmt = DbtPy.prepare(conn, statement)
        result = DbtPy.execute(stmt, (t_val, d_val, ts_val))
      else:
        statement = "CREATE TABLE tab_datetime (col1 TIME, col2 DATE, col3 TIMESTAMP)"
        result = DbtPy.exec_immediate(conn, statement)
        statement = "INSERT INTO tab_datetime (col1, col2, col3) values (?, ?, ?)"
        stmt = DbtPy.prepare(conn, statement)
        result = DbtPy.execute(stmt, (t_val, d_val, ts_val))

      statement = "SELECT * FROM tab_datetime"
      result = DbtPy.exec_immediate(conn, statement)
      
      for i in range(0, DbtPy.num_fields(result)):
        print(str(i) + ":" + DbtPy.field_type(result,i))

      statement = "SELECT * FROM tab_datetime"
      stmt = DbtPy.prepare(conn, statement)
      rc = DbtPy.execute(stmt)
      result = DbtPy.fetch_row(stmt)
      while ( result ):
        row0 = DbtPy.result(stmt, 0)
        row1 = DbtPy.result(stmt, 1)
        row2 = DbtPy.result(stmt, 2)
        print(type(row0), row0)
        print(type(row1), row1)
        print(type(row2), row2)
        result = DbtPy.fetch_row(stmt)
      
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#0:time
#1:date
#2:timestamp
#<%s 'datetime.time'> 10:42:34
#<%s 'datetime.date'> 1981-07-08
#<%s 'datetime.datetime'> 1981-07-08 10:42:34.000010
#__ZOS_EXPECTED__
#0:time
#1:date
#2:timestamp
#<%s 'datetime.time'> 10:42:34
#<%s 'datetime.date'> 1981-07-08
#<%s 'datetime.datetime'> 1981-07-08 10:42:34.000010
#__SYSTEMI_EXPECTED__
#0:time
#1:date
#2:timestamp
#<%s 'datetime.time'> 10:42:34
#<%s 'datetime.date'> 1981-07-08
#<%s 'datetime.datetime'> 1981-07-08 10:42:34.000010
#__IDS_EXPECTED__
#0:time
#1:date
#2:timestamp
#<%s 'datetime.time'> 10:42:34
#<%s 'datetime.date'> 1981-07-08
#<%s 'datetime.datetime'> 1981-07-08 10:42:34.000010



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_310_ClientInfo(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_310)

  def run_test_310(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    client = DbtPy.client_info(conn)
    
    if client:
      print("DRIVER_NAME: string(%d) \"%s\"" % (len(client.DRIVER_NAME), client.DRIVER_NAME))
      print("DRIVER_VER: string(%d) \"%s\"" % (len(client.DRIVER_VER), client.DRIVER_VER))
      print("DATA_SOURCE_NAME: string(%d) \"%s\"" % (len(client.DATA_SOURCE_NAME), client.DATA_SOURCE_NAME))
      print("DRIVER_ODBC_VER: string(%d) \"%s\"" % (len(client.DRIVER_ODBC_VER), client.DRIVER_ODBC_VER))
      print("ODBC_VER: string(%d) \"%s\"" % (len(client.ODBC_VER), client.ODBC_VER))
      print("ODBC_SQL_CONFORMANCE: string(%d) \"%s\"" % (len(client.ODBC_SQL_CONFORMANCE), client.ODBC_SQL_CONFORMANCE))
    
      DbtPy.close(conn)
    else:
      print("Error.")

#__END__
#__LUW_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__ZOS_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__SYSTEMI_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__IDS_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s



# 

#

#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_197_StatisticsIndexes(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_197)

  def run_test_197(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    if conn:
      try:
          rc = DbtPy.exec_immediate(conn, "DROP TABLE index_test")
      except:
          pass
      rc = DbtPy.exec_immediate(conn, "CREATE TABLE index_test (id INTEGER, data VARCHAR(50))")
      rc = DbtPy.exec_immediate(conn, "CREATE UNIQUE INDEX index1 ON index_test (id)")

      print("Test first index table:")
      if (server.DBMS_NAME[0:3] == 'Inf'):
        result = DbtPy.statistics(conn,None,config.user,"index_test",True)
      else:
        result = DbtPy.statistics(conn,None,None,"INDEX_TEST",True)
      row = DbtPy.fetch_tuple(result)
      ## skipping table info row. statistics returns informtation about table itself for gbasedbt ###
      if (server.DBMS_NAME[0:3] == 'Inf'):
        row = DbtPy.fetch_tuple(result)
      print(row[2])  # TABLE_NAME
      print(row[3])  # NON_UNIQUE
      print(row[5])  # INDEX_NAME
      print(row[8])  # COLUMN_NAME

      try:
          rc = DbtPy.exec_immediate(conn, "DROP TABLE index_test2")
      except:
          pass
      rc = DbtPy.exec_immediate(conn, "CREATE TABLE index_test2 (id INTEGER, data VARCHAR(50))")
      rc = DbtPy.exec_immediate(conn, "CREATE INDEX index2 ON index_test2 (data)")

      print("Test second index table:")
      if (server.DBMS_NAME[0:3] == 'Inf'):
        result = DbtPy.statistics(conn,None,config.user,"index_test2",True)
      else:
        result = DbtPy.statistics(conn,None,None,"INDEX_TEST2",True)
      row = DbtPy.fetch_tuple(result)
      ### skipping table info row. statistics returns informtation about table itself for gbasedbt ###
      if (server.DBMS_NAME[0:3] == 'Inf'):
        row = DbtPy.fetch_tuple(result)
      print(row[2])  # TABLE_NAME
      print(row[3])  # NON_UNIQUE
      print(row[5])  # INDEX_NAME
      print(row[8])  # COLUMN_NAME

      print("Test non-existent table:")
      if (server.DBMS_NAME[0:3] == 'Inf'):
        result = DbtPy.statistics(conn,None,config.user,"non_existent_table",True)
      else:
        result = DbtPy.statistics(conn,None,None,"NON_EXISTENT_TABLE",True)
      row = DbtPy.fetch_tuple(result)
      if row:
        print("Non-Empty")
      else:
        print("Empty")
    else:
      print('no connection: ' + DbtPy.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__ZOS_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__SYSTEMI_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__IDS_EXPECTED__
#Test first index table:
#index_test
#0
#index1
#id
#Test second index table:
#index_test2
#1
#index2
#data
#Test non-existent table:
#Empty



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_102_NumFieldsSelect_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_102)

  def run_test_102(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if (not conn):
      print(DbtPy.conn_errormsg())
    
    server = DbtPy.server_info( conn )
    if ((server.DBMS_NAME[0:2] != "AS") and (server.DBMS_NAME != "DB2") and (server.DBMS_NAME[0:3] != "Inf")):
      result = DbtPy.exec_immediate(conn, "VALUES(1)")
      #throw :unsupported unless result
      if (not result):
        raise Exception('Unsupported')
      print(DbtPy.num_fields(result))
    else:
      print('1')
    DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_232_FieldTypePosName(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_232)

  def run_test_232(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    result = DbtPy.exec_immediate(conn, "select * from sales")
     
    for i in range(0, DbtPy.num_fields(result) + 1):
      field_name = DbtPy.field_name(result,i)
      field_type = DbtPy.field_type(result, DbtPy.field_name(result,i))
      print(str(DbtPy.field_name(result, i)) + ":" + str(DbtPy.field_type(result, DbtPy.field_name(result, i))))
          
    print("-----")
    
    t = DbtPy.field_type(result,99)
    print(t)
    
    t1 = DbtPy.field_type(result, "HELMUT")
    print(t1)

#__END__
#__LUW_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__ZOS_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__SYSTEMI_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__IDS_EXPECTED__
#sales_date:date
#sales_person:string
#region:string
#sales:int
#False:False
#-----
#False
#False



# 

#

#

import unittest, sys
import DbtPy
import config
import os
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_112_FieldNumDiffCaseColNames(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_112)

  def run_test_112(self):
    os.environ['DELIMIDENT'] = 'y'
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    if conn:
      drop = "DROP TABLE ftest"
      try:
        DbtPy.exec_immediate( conn, drop )
      except:
        pass
      
      create = "CREATE TABLE ftest ( \"TEST\" INTEGER, \"test\" INTEGER, \"Test\" INTEGER  )"
      DbtPy.exec_immediate(conn, create)
      
      insert = "INSERT INTO ftest VALUES (1,2,3)"
      DbtPy.exec_immediate(conn, insert)
      
      stmt = DbtPy.exec_immediate(conn, "SELECT * FROM ftest")
    
      num1 = DbtPy.field_num(stmt, "TEST")
      num2 = DbtPy.field_num(stmt, 'test')
      num3 = DbtPy.field_num(stmt, 'Test')
      
      print("int(%d)" % num1)
      print("int(%d)" % num2)
      print("int(%d)" % num3)
      
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#int(0)
#int(1)
#int(2)



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_004_ConnWrongUserPwd(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_004)

  def run_test_004(self):
    try:
      conn = DbtPy.connect("sample", "not_a_user", "inv_pass")
    except:
      print("connect failed, test succeeded")
      return -1
    print("connect succeeded? Test failed")

#__END__
#__LUW_EXPECTED__
#connect failed, test succeeded
#__ZOS_EXPECTED__
#connect failed, test succeeded
#__SYSTEMI_EXPECTED__
#connect failed, test succeeded
#__IDS_EXPECTED__
#connect failed, test succeeded



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_082_ConnWrongPwd(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_082)

  def run_test_082(self):
    try:
      conn = DbtPy.connect(config.ConnStr, config.user, "z")
      print("??? No way.")
    except:
      err = DbtPy.conn_error()
      print(err)

#__END__
#__IDS_EXPECTED__
#28000



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_143_BindParamInsertStmtNoneParam(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_143)

  def run_test_143(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)

    insert1 = "INSERT INTO animals (id, breed, name, weight) VALUES (NULL, 'ghost', NULL, ?)"
    select = 'SELECT id, breed, name, weight FROM animals WHERE weight IS NULL'
    
    if conn:
      stmt = DbtPy.prepare(conn, insert1)
    
      animal = None
      DbtPy.bind_param(stmt, 1, animal)
    
      if DbtPy.execute(stmt):
        stmt = DbtPy.exec_immediate(conn, select)
        row = DbtPy.fetch_tuple(stmt)
        while ( row ):
          #row.each { |child| print child }
          for i in row:
            print(i)
          row = DbtPy.fetch_tuple(stmt)

      DbtPy.rollback(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#None
#ghost
#None
#None
#__ZOS_EXPECTED__
#None
#ghost
#None
#None
#__SYSTEMI_EXPECTED__
#None
#ghost
#None
#None
#__IDS_EXPECTED__
#None
#ghost
#None
#None



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_022_RollbackInsert(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_022)

  def run_test_022(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      
    if conn:
      stmt = DbtPy.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = DbtPy.fetch_tuple(stmt)
      rows = res[0]
      print(rows)
        
      DbtPy.autocommit(conn, 0)
      ac = DbtPy.autocommit(conn)
      if ac != 0:
        print("Cannot set DbtPy.AUTOCOMMIT_OFF\nCannot run test")
        #continue
        
      DbtPy.exec_immediate(conn, "INSERT INTO animals values (7,'bug','Brain Bug',10000.1)")
        
      stmt = DbtPy.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = DbtPy.fetch_tuple(stmt)
      rows = res[0]
      print(rows)
        
      DbtPy.rollback(conn)
      
      stmt = DbtPy.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = DbtPy.fetch_tuple(stmt)
      rows = res[0]
      print(rows)
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#7
#8
#7
#__ZOS_EXPECTED__
#7
#8
#7
#__SYSTEMI_EXPECTED__
#7
#8
#7
#__IDS_EXPECTED__
#7
#8
#7



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_210_FieldDisplaySize_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_210)

  def run_test_210(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from staff")
    cols = DbtPy.num_fields(result)
    
    for i in range(0, cols):
      size = DbtPy.field_display_size(result,i)
      print("col:%d and size: %d" % (i, size))
    
    DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#col:0 and size: 6
#col:1 and size: 9
#col:2 and size: 6
#col:3 and size: 5
#col:4 and size: 6
#col:5 and size: 9
#col:6 and size: 9
#__ZOS_EXPECTED__
#col:0 and size: 6
#col:1 and size: 9
#col:2 and size: 6
#col:3 and size: 5
#col:4 and size: 6
#col:5 and size: 9
#col:6 and size: 9
#__SYSTEMI_EXPECTED__
#col:0 and size: 6
#col:1 and size: 9
#col:2 and size: 6
#col:3 and size: 5
#col:4 and size: 6
#col:5 and size: 9
#col:6 and size: 9
#__IDS_EXPECTED__
#col:0 and size: 6
#col:1 and size: 9
#col:2 and size: 6
#col:3 and size: 5
#col:4 and size: 6
#col:5 and size: 9
#col:6 and size: 9



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_251_FreeResult_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_251)

  def run_test_251(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from sales")
    
    r1 = DbtPy.free_result(result)
    r2 = DbtPy.free_result(result)
    r3 = ''
    try:
      r3 = DbtPy.free_result(result99)
    except:
      r3 = None
    
    print(r1)
    print(r2)
    print(r3)

#__END__
#__LUW_EXPECTED__
#True
#True
#None
#__ZOS_EXPECTED__
#True
#True
#None
#__SYSTEMI_EXPECTED__
#True
#True
#None
#__IDS_EXPECTED__
#True
#True
#None



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_6561_InsertNULLValues(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_6561)

  def run_test_6561(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)

      stmt = DbtPy.exec_immediate(conn, "INSERT INTO animals (id, breed, name, weight) VALUES (null, null, null, null)")
      statement = "SELECT count(id) FROM animals"
      result = DbtPy.exec_immediate(conn, statement)
      if ( (not result) and DbtPy.stmt_error() ):
        print("ERROR: %s" % (DbtPy.stmt_errormsg(), ))

      row = DbtPy.fetch_tuple(result)
      while ( row ):
        for i in row:
            print(i)
        row = DbtPy.fetch_tuple(result)
    
      DbtPy.rollback(conn)
      DbtPy.close(conn)
      
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#7
#__ZOS_EXPECTED__
#7
#__SYSTEMI_EXPECTED__
#7
#__IDS_EXPECTED__
#7



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_125_FieldNamePos_03(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_125)

  def run_test_125(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    result = DbtPy.exec_immediate(conn, "SELECT * FROM sales")
    result2 = DbtPy.exec_immediate(conn, "SELECT * FROM staff")
    
    for i in range(0, DbtPy.num_fields(result)):
      print("%d:%s" % (i, DbtPy.field_name(result,i)))
    
    print("-----")
    
    for i in range(0, DbtPy.num_fields(result2)):
      print("%d:%s" % (i, DbtPy.field_name(result2,i)))
    
    print("-----")
    
    if (server.DBMS_NAME[0:3] == 'Inf'):
      print("Region:%s" % DbtPy.field_name(result, 'region'))
    else:
      print("Region:%s" % DbtPy.field_name(result, 'REGION'))
    print("5:%s" % DbtPy.field_name(result2, 5))

#__END__
#__LUW_EXPECTED__
#0:SALES_DATE
#1:SALES_PERSON
#2:REGION
#3:SALES
#
#-----
#0:ID
#1:NAME
#2:DEPT
#3:JOB
#4:YEARS
#5:SALARY
#6:COMM
#
#-----
#Region:REGION
#5:SALARY
#__ZOS_EXPECTED__
#0:SALES_DATE
#1:SALES_PERSON
#2:REGION
#3:SALES
#
#-----
#0:ID
#1:NAME
#2:DEPT
#3:JOB
#4:YEARS
#5:SALARY
#6:COMM
#
#-----
#Region:REGION
#5:SALARY
#__SYSTEMI_EXPECTED__
#0:SALES_DATE
#1:SALES_PERSON
#2:REGION
#3:SALES
#
#-----
#0:ID
#1:NAME
#2:DEPT
#3:JOB
#4:YEARS
#5:SALARY
#6:COMM
#
#-----
#Region:REGION
#5:SALARY
#__IDS_EXPECTED__
#0:sales_date
#1:sales_person
#2:region
#3:sales
#
#-----
#0:id
#1:name
#2:dept
#3:job
#4:years
#5:salary
#6:comm
#
#-----
#Region:region
#5:salary



#

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_053_AttrThruConn(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_053)

  def run_test_053(self):
    print("Client attributes passed through conection string:")

    options1 = {DbtPy.SQL_ATTR_INFO_USERID: 'db2inst1'}
    conn1 = DbtPy.connect(config.ConnStr, config.user, config.password, options1)
    val = DbtPy.get_option(conn1, DbtPy.SQL_ATTR_INFO_USERID, 1)
    print(val)

    options2 = {DbtPy.SQL_ATTR_INFO_ACCTSTR: 'account'}
    conn2 = DbtPy.connect(config.ConnStr, config.user, config.password, options2)
    val = DbtPy.get_option(conn2, DbtPy.SQL_ATTR_INFO_ACCTSTR, 1)
    print(val)

    options3 = {DbtPy.SQL_ATTR_INFO_APPLNAME: 'myapp'}
    conn3 = DbtPy.connect(config.ConnStr, config.user, config.password, options3)
    val = DbtPy.get_option(conn3, DbtPy.SQL_ATTR_INFO_APPLNAME, 1)
    print(val)

    options4 = {DbtPy.SQL_ATTR_INFO_WRKSTNNAME: 'workstation'}
    conn4 = DbtPy.connect(config.ConnStr, config.user, config.password, options4)
    val = DbtPy.get_option(conn4, DbtPy.SQL_ATTR_INFO_WRKSTNNAME, 1)
    print(val)

    options5 = {DbtPy.SQL_ATTR_INFO_USERID: 'kfb',
                DbtPy.SQL_ATTR_INFO_WRKSTNNAME: 'kfbwork',
                DbtPy.SQL_ATTR_INFO_ACCTSTR: 'kfbacc',
                DbtPy.SQL_ATTR_INFO_APPLNAME: 'kfbapp'}
    conn5 = DbtPy.connect(config.ConnStr, config.user, config.password, options5)
    val = DbtPy.get_option(conn5, DbtPy.SQL_ATTR_INFO_USERID, 1)
    print(val)
    val = DbtPy.get_option(conn5, DbtPy.SQL_ATTR_INFO_ACCTSTR, 1)
    print(val)
    val = DbtPy.get_option(conn5, DbtPy.SQL_ATTR_INFO_APPLNAME, 1)
    print(val)
    val = DbtPy.get_option(conn5, DbtPy.SQL_ATTR_INFO_WRKSTNNAME, 1)
    print(val)

    print("Client attributes passed post-conection:")

    options5 = {DbtPy.SQL_ATTR_INFO_USERID: 'db2inst1'}
    conn5 = DbtPy.connect(config.ConnStr, config.user, config.password)
    rc = DbtPy.set_option(conn5, options5, 1)
    val = DbtPy.get_option(conn5, DbtPy.SQL_ATTR_INFO_USERID, 1)
    print(val)

    options6 = {DbtPy.SQL_ATTR_INFO_ACCTSTR: 'account'}
    conn6 = DbtPy.connect(config.ConnStr, config.user, config.password)
    rc = DbtPy.set_option(conn6, options6, 1)
    val = DbtPy.get_option(conn6, DbtPy.SQL_ATTR_INFO_ACCTSTR, 1)
    print(val)

    options7 = {DbtPy.SQL_ATTR_INFO_APPLNAME: 'myapp'}
    conn7 = DbtPy.connect(config.ConnStr, config.user, config.password)
    rc = DbtPy.set_option(conn7, options7, 1)
    val = DbtPy.get_option(conn7, DbtPy.SQL_ATTR_INFO_APPLNAME, 1)
    print(val)

    options8 = {DbtPy.SQL_ATTR_INFO_WRKSTNNAME: 'workstation'}
    conn8 = DbtPy.connect(config.ConnStr, config.user, config.password)
    rc = DbtPy.set_option(conn8, options8, 1)
    val = DbtPy.get_option(conn8, DbtPy.SQL_ATTR_INFO_WRKSTNNAME, 1)
    print(val)

#__END__
#__LUW_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation
#__ZOS_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation
#__SYSTEMI_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation
#__IDS_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_6528_ScopingProblemBindParam(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_6528)

  def checked_ids_execute(self, stmt):
    DbtPy.execute(stmt)
    row = DbtPy.fetch_tuple(stmt)
    for i in row:
      print(i)

  def run_test_6528(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    if conn:
      if (server.DBMS_NAME[0:3] == 'Inf'):
        sql = "SELECT TRIM(TRAILING FROM name) FROM animals WHERE breed = ?"
      else:
        sql = "SELECT RTRIM(name) FROM animals WHERE breed = ?"
      stmt = DbtPy.prepare(conn, sql)
      var = "cat"
      DbtPy.bind_param(stmt, 1, var, DbtPy.SQL_PARAM_INPUT)
      self.checked_ids_execute(stmt)
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Pook
#__ZOS_EXPECTED__
#Pook
#__SYSTEMI_EXPECTED__
#Pook
#__IDS_EXPECTED__
#Pook



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_019_selectRowcountPrefetchPrepOpt(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_019)

  def run_test_019(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_ON)
    if conn:
      stmt = DbtPy.prepare(conn, "SELECT * from animals WHERE weight < 10.0", {DbtPy.SQL_ATTR_ROWCOUNT_PREFETCH : DbtPy.SQL_ROWCOUNT_PREFETCH_ON} )
      result = DbtPy.execute(stmt)
      if result:
        rows = DbtPy.num_rows(stmt)
        print("affected row:", rows)
        DbtPy.free_result(stmt)
      else:
        print(DbtPy.stmt_errormsg())

      DbtPy.close(conn)
    else:
      print("no connection:", DbtPy.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#affected row: 4
#__ZOS_EXPECTED__
#affected row: 4
#__SYSTEMI_EXPECTED__
#affected row: 4
#__IDS_EXPECTED__
#affected row: 4



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_092_ConnmsgWrongPwd(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_092)

  def run_test_092(self):
    try:
      conn = DbtPy.connect(config.ConnStr, config.user, "z")
      print("??? No way.")
    except:
      err = DbtPy.conn_errormsg()
      print(err[0:68])

#__END__
#__IDS_EXPECTED__
#[GBasedbt][GBase ODBC Driver][GBasedbt]Incorrect password or user



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_081_ConnWrongUser(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_081)

  def run_test_081(self):
    try:
      conn = DbtPy.connect(config.ConnStr, "y", config.password)
      print("??? No way.")
    except:
      print(DbtPy.conn_error())

    #if conn:
    #  print "??? No way."
    #else:
    #  err = DbtPy.conn_error 
    #  print err

#__END__
#__IDS_EXPECTED__
#28000


# 

#

#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_024_ForeignKeys(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_024)

  def run_test_024(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )
     
    if conn != 0:
      drop = 'DROP TABLE test_primary_keys'
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass
      drop = 'DROP TABLE test_keys'
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass
      drop = 'DROP TABLE test_foreign_keys'
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass

      statement = 'CREATE TABLE test_primary_keys (id INTEGER NOT NULL, PRIMARY KEY(id))'
      result = DbtPy.exec_immediate(conn, statement)
      statement = "INSERT INTO test_primary_keys VALUES (1)"
      result = DbtPy.exec_immediate(conn, statement)
      statement = 'CREATE TABLE test_keys (name VARCHAR(30) NOT NULL, idf INTEGER NOT NULL, FOREIGN KEY(idf) REFERENCES test_primary_keys(id), \
                   PRIMARY KEY(name))'
      result = DbtPy.exec_immediate(conn, statement)
      statement = "INSERT INTO test_keys VALUES ('vince', 1)"
      result = DbtPy.exec_immediate(conn, statement)
      statement = 'CREATE TABLE test_foreign_keys (namef VARCHAR(30) NOT NULL, id INTEGER NOT NULL, FOREIGN KEY(namef) REFERENCES test_keys(name))'
      result = DbtPy.exec_immediate(conn, statement)
      statement = "INSERT INTO test_foreign_keys VALUES ('vince', 1)"
      result = DbtPy.exec_immediate(conn, statement)

      stmt = DbtPy.foreign_keys(conn, None, config.user, 'test_primary_keys')
      
      row = DbtPy.fetch_tuple(stmt)
      print(row[2])
      print(row[3])
      print(row[6])
      print(row[7])

      stmt = DbtPy.foreign_keys(conn, None, None, None, None, config.user, 'test_keys')
      row = DbtPy.fetch_tuple(stmt)
      print(row[2])
      print(row[3])
      print(row[6])
      print(row[7])

      stmt = DbtPy.foreign_keys(conn, None, config.user, 'test_keys', None, None, None)
      row = DbtPy.fetch_tuple(stmt)
      print(row[2])
      print(row[3])
      print(row[6])
      print(row[7])

      stmt = DbtPy.foreign_keys(conn, None, config.user, 'test_keys', None, config.user, 'test_foreign_keys')
      row = DbtPy.fetch_tuple(stmt)
      print(row[2])
      print(row[3])
      print(row[6])
      print(row[7])

      stmt = DbtPy.foreign_keys(conn, None, config.user, 'test_keys', None, 'dummy_schema')
      row = DbtPy.fetch_tuple(stmt)
      if(not row):
        print("No Data Found")
      else:
        print(row[2])
        print(row[3])
        print(row[6])
        print(row[7])
      DbtPy.close(conn)
    else:
      print(DbtPy.conn_errormsg())
      print("Connection failed\n")

#__END__
#__IDS_EXPECTED__
#test_primary_keys
#id
#test_keys
#idf
#test_primary_keys
#id
#test_keys
#idf
#test_keys
#name
#test_foreign_keys
#namef
#test_keys
#name
#test_foreign_keys
#namef
#test_keys
#name
#test_foreign_keys
#namef



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_013_KeysetDrivenCursorSelect02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_013)

  def run_test_013(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      
    if conn:
      serverinfo = DbtPy.server_info( conn )
      if (serverinfo.DBMS_NAME[0:3] != 'Inf'):
        stmt = DbtPy.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0", {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_KEYSET_DRIVEN})
      else:
        stmt = DbtPy.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0")
      DbtPy.execute(stmt)
      data = DbtPy.fetch_both( stmt )
      while (data):
        print(data[0])
        data = DbtPy.fetch_both( stmt )
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#__ZOS_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#__SYSTEMI_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#__IDS_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    



#

#

#

import unittest, sys, os
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):
    def test_315_UDT(self):
        obj = DbtPyTestFunctions()
        obj.assert_expect(self.run_test_315)

    def run_test_315(self):
        conn = DbtPy.connect(config.ConnStr, config.user, config.password)

        server = DbtPy.server_info( conn )

        try:
            sql = "drop table t31;"
            stmt = DbtPy.exec_immediate(conn, sql)
        except:
            pass

        sql = "DROP ROW TYPE if exists udt_t4 RESTRICT;"
        DbtPy.exec_immediate(conn, sql)

        sql = " create ROW type udt_t4 (a int);"
        stmt = DbtPy.exec_immediate(conn, sql)

        SetupSqlSet = [
            "create table t31 ( c1 int, c2 char(20), c3 int, c4 udt_t4 ) ;",
            "insert into t31 values( 1, 'Sunday', 101, (ROW(201)::udt_t4) );",
            "insert into t31 values( 2, 'Monday', 102, (ROW(202)::udt_t4) );"
        ]

        i = 0
        for sql in SetupSqlSet:
            i += 1
            stmt = DbtPy.exec_immediate(conn, sql)

        # The first record executed is for create table
        i -= 1

        # Select records
        sql = "SELECT * FROM t31"
        stmt = DbtPy.exec_immediate(conn, sql)
        dictionary = DbtPy.fetch_both(stmt)

        print("UDT complete")

#__END__
#__LUW_EXPECTED__
#UDT complete
#__ZOS_EXPECTED__
#UDT complete
#__SYSTEMI_EXPECTED__
#UDT complete
#__IDS_EXPECTED__
#UDT complete



# 

#

#

import unittest, sys, os
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_144_BindParamInsertStmtPARAM_FILE(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_144)

  def run_test_144(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      # Drop the test table, in case it exists
      drop = 'DROP TABLE pictures'
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass
      
      # Create the test table
      create = 'CREATE TABLE pictures (id INTEGER, picture BLOB)'
      result = DbtPy.exec_immediate(conn, create)
      
      stmt = DbtPy.prepare(conn, "INSERT INTO pictures VALUES (0, ?)")
      
      picture = os.path.dirname(os.path.abspath(__file__)) + "/pic1.jpg"
      rc = DbtPy.bind_param(stmt, 1, picture, DbtPy.SQL_PARAM_INPUT)
    
      rc = DbtPy.execute(stmt)
      
      num = DbtPy.num_rows(stmt)
      
      print(num)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_050_AutocommitStatus(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_050)

  def run_test_050(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
     
    ac = DbtPy.autocommit(conn)
      
    print(ac)

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_001_ConnDb(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_001)

  def run_test_001(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      
    if conn:
      print("Connection succeeded.")
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Connection succeeded.
#__ZOS_EXPECTED__
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Connection succeeded.
#__IDS_EXPECTED__
#Connection succeeded.





import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class Wrapper(str):
  def __del__(self):
    print("Wrapper(" + self + ") being deleted")

class DbtPyTestCase(unittest.TestCase):

  def test_312_CacheBoundParameters(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_312)
  
  def run_test_312(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)
    
    query = "INSERT INTO department (deptno, deptname, mgrno, admrdept, location) VALUES (?, ?, ?, ?, ?)"
    
    if conn:
      stmt = DbtPy.prepare(conn, query)
      params = ['STG', 'Systems & Technology', '123456', 'RSF', 'Fiji']

      print("Binding parameters")
      for i,p in enumerate(params, 1):
        DbtPy.bind_param(stmt, i, Wrapper(p))
      
      if DbtPy.execute(stmt):
        print("Executing statement")
        DbtPy.execute(stmt)

        # force the cache to be unbound
        for i,p in enumerate(params, 1):
          DbtPy.bind_param(stmt, i, p)
        
        DbtPy.rollback(conn)
      else:
        print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Binding parameters
#Executing statement
#Wrapper(STG) being deleted
#Wrapper(Systems & Technology) being deleted
#Wrapper(123456) being deleted
#Wrapper(RSF) being deleted
#Wrapper(Fiji) being deleted
#__ZOS_EXPECTED__
#Binding parameters
#Executing statement
#Wrapper(STG) being deleted
#Wrapper(Systems & Technology) being deleted
#Wrapper(123456) being deleted
#Wrapper(RSF) being deleted
#Wrapper(Fiji) being deleted
#__SYSTEMI_EXPECTED__
#Binding parameters
#Executing statement
#Wrapper(STG) being deleted
#Wrapper(Systems & Technology) being deleted
#Wrapper(123456) being deleted
#Wrapper(RSF) being deleted
#Wrapper(Fiji) being deleted
#__IDS_EXPECTED__
#Binding parameters
#Executing statement
#Wrapper(STG) being deleted
#Wrapper(Systems & Technology) being deleted
#Wrapper(123456) being deleted
#Wrapper(RSF) being deleted
#Wrapper(Fiji) being deleted



import DbtPy
from ctypes import *
import threading
import os

def printme1(outValue1):
   "This prints a passed string into this function1"
   print ("\nTest for callback function, value = ", outValue1)
   return

def printme2(outValue2):
   "This prints a passed string into this function2"
   print ("\nTest for callback function, value = ", outValue2)
   return
 
def task1():
    print("Task 1 assigned to thread: {}".format(threading.current_thread().name))
    print("ID of process running task 1: {}".format(os.getpid()))
    temp4 = DbtPy.register_smart_trigger_loop(conn, printme1, temp, "t1", "gbasedbt", "sheshdb", "select * from t1;", "label1", False, False)
    #temp4 = DbtPy.register_smart_trigger_loop(conn, printme1, temp, "बस", "gbasedbt", "sheshdb_utf8", "select * from बस;", "label1", False, False)
 
def task2():
    print("Task 2 assigned to thread: {}".format(threading.current_thread().name))
    print("ID of process running task 2: {}".format(os.getpid()))
    #temp5 = DbtPy.register_smart_trigger_loop(conn, printme2, temp, "t2", "gbasedbt", "sheshdb", "select * from t2;", "label2", False, False)
    temp5 = DbtPy.register_smart_trigger_loop(conn, printme2, temp, "t2", "gbasedbt", "sheshdb_utf8", "select * from t2;", "label2", False, False)
 
# if __name__ == "__main__":
             
# ConStr = "SERVER=ol_gbasedbt1210;DATABASE=sheshdb_utf8;HOST=127.0.0.1;SERVICE=1067;UID=gbasedbt;PWD=xxxx;DB_LOCALE=en_us.utf8;CLIENT_LOCALE=en_us.UTF8;"
ConStr = "SERVER=ol_gbasedbt1210;DATABASE=sheshdb;HOST=127.0.0.1;SERVICE=1067;UID=gbasedbt;PWD=IFMX4pass;"

conn = DbtPy.connect( ConStr, "", "")

temp = DbtPy.open_smart_trigger(conn, "Unique1", False, 5, 1, 0)
print ("\nFile descriptor = ", temp)
 
# creating threads
t1 = threading.Thread(target=task1, name='t1')
t2 = threading.Thread(target=task2, name='t2')  
 
# starting threads
t1.start()
t2.start()
 
# wait until all threads finish
t1.join()
t2.join()

DbtPy.close(conn)
print ("Done")


# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_091_ConnmsgWrongUser(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_091)

  def run_test_091(self):
    try:
      conn = DbtPy.connect(config.ConnStr, "y", config.password)
      print("??? No way.")
    except:
      err = DbtPy.conn_errormsg()
      print(err[0:68])

#__END__
#__LUW_EXPECTED__
#__IDS_EXPECTED__
#[GBasedbt][GBase ODBC Driver][GBasedbt]Incorrect password or user



# 

#

#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_191_ColumnsTable_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_191)

  def run_test_191(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    if conn:
      result = DbtPy.columns(conn,None,config.user,"emp_photo");    

      i = 0
      row = DbtPy.fetch_both(result)
      while ( row ):
        if ( (row['COLUMN_NAME'] != 'emp_rowid') and (i < 3) ):
          print("%s,%s,%s,%s\n" % (row['TABLE_SCHEM'], 
          row['TABLE_NAME'], row['COLUMN_NAME'], row['IS_NULLABLE']))
        i = i + 1
        row = DbtPy.fetch_both(result)
      print("done!")
    else:
      print("no connection: ", DbtPy.conn_errormsg())    

#__END__
#__IDS_EXPECTED__
#%s,emp_photo,empno,NO
#%s,emp_photo,photo_format,NO
#%s,emp_photo,picture,YES
#done!



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_110_FieldNum(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_110)

  def run_test_110(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )
    
    if conn:
      stmt = DbtPy.exec_immediate(conn, "SELECT * FROM animals ORDER BY breed")
    
      num1 = DbtPy.field_num(stmt, "id")
      num2 = DbtPy.field_num(stmt, "breed")
      num3 = DbtPy.field_num(stmt, "name")
      num4 = DbtPy.field_num(stmt, "weight")
      num5 = DbtPy.field_num(stmt, "test")
      num6 = DbtPy.field_num(stmt, 8)
      num7 = DbtPy.field_num(stmt, 1)
      num8 = DbtPy.field_num(stmt, "WEIGHT")
      
      print("int(%d)" % num1)
      print("int(%d)" % num2)
      print("int(%d)" % num3)
      print("int(%d)" % num4)
      
      print("%s" % num5)
      print("%s" % num6)
      print("int(%d)" % num7)
      print("%s" % num8)
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#int(0)
#int(1)
#int(2)
#int(3)
#False
#False
#int(1)
#False



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_200_MultipleRsltsetsUniformColDefs(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_200)

  def run_test_200(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    serverinfo = DbtPy.server_info( conn )
   
    procedure = """
  	CREATE FUNCTION multiResults()
  	 RETURNING CHAR(16), INT;
  			
  	 DEFINE p_name CHAR(16);
  	 DEFINE p_id INT;
  		   
  	 FOREACH c1 FOR
  		 SELECT name, id
  		  INTO p_name, p_id
  		   FROM animals
  		   ORDER BY name
  		  RETURN p_name, p_id WITH RESUME;
  	 END FOREACH;
  			
    END FUNCTION;
    """
    
    if conn:
     try:
       DbtPy.exec_immediate(conn, 'DROP PROCEDURE multiResults')
     except:
       pass
     DbtPy.exec_immediate(conn, procedure)
     stmt = DbtPy.exec_immediate(conn, 'CALL multiResults()')
    
     print("Fetching first result set")
     row = DbtPy.fetch_tuple(stmt)
     while ( row ):
       for i in row:
         print(i)
       row = DbtPy.fetch_tuple(stmt)
    
     DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#Fetching first result set
#Bubbles         
#3
#Gizmo           
#4
#Peaches         
#1
#Pook            
#0
#Rickety Ride    
#5
#Smarty          
#2
#Sweater         
#6



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_070_Close(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_070)

  def run_test_070(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      if (type(conn) == DbtPy.IFXConnection):
        print("Resource is a Ifx Connection")
      
      rc = DbtPy.close(conn)
      
      print(rc)
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#Resource is a Ifx Connection
#True




import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):
    def test_warn(self):
        obj = DbtPyTestFunctions()
        obj.assert_expect(self.run_test_warn)

    def run_test_warn(self):
        conn = DbtPy.connect(config.ConnStr, config.user, config.password)
            
        if conn:

            drop = "DROP TABLE TEST1"
            try:
                result = DbtPy.exec_immediate(conn,drop)
            except:
                pass

            # Create the table test1

            create = "CREATE TABLE TEST1 (COL1 CHAR(5))"
            result = DbtPy.exec_immediate(conn, create)

            # Insert a string longer than 5 characters to force an error 
            # DbtPy.stmt_warn() API

            query = 'INSERT INTO TEST1 VALUES (?)'
            stmt = DbtPy.prepare(conn, query)
            try:
                DbtPy.execute(stmt, ('ABCDEF',))
            except:
                pass
				
            print((DbtPy.stmt_warn(stmt)))
			
            DbtPy.close(conn)
        else:
            print ("Connection failed.")

#__END__
#__IDS_EXPECTED__
#[GBasedbt][GBase ODBC Driver]String data right truncation. SQLCODE=-11023



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_113_DateTest(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_113)

  def run_test_113(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      drop = "DROP TABLE datetest"
      try:
        DbtPy.exec_immediate( conn, drop )
      except:
        pass
      
      create = "CREATE TABLE datetest ( id INTEGER, mydate DATE )"
      DbtPy.exec_immediate(conn, create)

      insert = "INSERT INTO datetest (id, mydate) VALUES (1,'03-27-1982')"
      DbtPy.exec_immediate(conn, insert)
      insert = "INSERT INTO datetest (id, mydate) VALUES (2,'07-08-1981')"
      DbtPy.exec_immediate(conn, insert)
      
      stmt = DbtPy.prepare(conn, "SELECT * FROM datetest")
      DbtPy.execute(stmt)

      result = DbtPy.fetch_row( stmt )
      while ( result ):
        row0 = DbtPy.result(stmt, 0)
        row1 = DbtPy.result(stmt, 1)
        print(row0)
        print(row1)
        result = DbtPy.fetch_row( stmt )
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_066_TableObjects(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_066)

  def run_test_066(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    result = DbtPy.tables(conn, None, config.user.lower(), 'animals')
      
#    NOTE: This is a workaround
#    function fetch_object() to be implemented...
#    row = DbtPy.fetch_object(result)
#    JS: check .lower() functionatily  
  
    class Row:
        pass

    data = DbtPy.fetch_assoc(result)
    while ( data ):
      row = Row()
      row.table_schem = data['TABLE_SCHEM']
      row.table_name = data['TABLE_NAME']
      row.table_type = data['TABLE_TYPE']
      row.remarks = data['REMARKS']
          
      print("Schema:  %s" % row.table_schem)
      print("Name:    %s" % row.table_name)
      print("Type:    %s" % row.table_type)
      print("Remarks: %s\n" % row.remarks)
#      row = DbtPy.fetch_object(result)
      data = DbtPy.fetch_assoc(result)

    result = DbtPy.tables(conn, None, config.user.lower(), 'animal_pics')
    
#    row = DbtPy.fetch_object(result)
    data = DbtPy.fetch_assoc(result)
    while (data ):
      row = Row()
      row.table_schem = data['TABLE_SCHEM']
      row.table_name = data['TABLE_NAME']
      row.table_type = data['TABLE_TYPE']
      row.remarks = data['REMARKS']
        
      print("Schema:  %s" % row.table_schem)
      print("Name:    %s" % row.table_name)
      print("Type:    %s" % row.table_type)
      print("Remarks: %s\n" % row.remarks)
      data = DbtPy.fetch_assoc(result)
      
    result = DbtPy.tables(conn, None, config.user.lower(), 'anime_cat')
    
#    row = DbtPy.fetch_object(result)
    data = DbtPy.fetch_assoc(result)
    while ( data ): 
      row = Row()
      row.table_schem = data['TABLE_SCHEM']
      row.table_name = data['TABLE_NAME']
      row.table_type = data['TABLE_TYPE']
      row.remarks = data['REMARKS']
        
      print("Schema:  %s" % row.table_schem)
      print("Name:    %s" % row.table_name)
      print("Type:    %s" % row.table_type)
      print("Remarks: %s\n" % row.remarks)
#      row = DbtPy.fetch_object(result)
      data = DbtPy.fetch_assoc(result)
    
    DbtPy.free_result(result)
    DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#Schema:  %s
#Name:    ANIMALS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIMAL_PICS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIME_CAT
#Type:    VIEW
#Remarks: None
#__ZOS_EXPECTED__
#Schema:  %s
#Name:    ANIMALS
#Type:    TABLE
#Remarks: 
#
#Schema:  %s
#Name:    ANIMAL_PICS
#Type:    TABLE
#Remarks: 
#
#Schema:  %s
#Name:    ANIME_CAT
#Type:    VIEW
#Remarks: 
#__SYSTEMI_EXPECTED__
#Schema:  %s
#Name:    ANIMALS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIMAL_PICS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIME_CAT
#Type:    VIEW
#Remarks: None
#__IDS_EXPECTED__
#Schema:  %s
#Name:    animals
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    animal_pics
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    anime_cat
#Type:    VIEW
#Remarks: None



#

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_054_CursorType(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_054)

  def run_test_054(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    serverinfo = DbtPy.server_info( conn )

    stmt = DbtPy.exec_immediate(conn, "SELECT * FROM animals")
    val = DbtPy.get_option(stmt, DbtPy.SQL_ATTR_CURSOR_TYPE, 0)
    print(val)

    op = {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_FORWARD_ONLY}
    stmt = DbtPy.exec_immediate(conn, "SELECT * FROM animals", op)
    val = DbtPy.get_option(stmt, DbtPy.SQL_ATTR_CURSOR_TYPE, 0)
    print(val)

    op = {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_KEYSET_DRIVEN}
    stmt = DbtPy.exec_immediate(conn, "SELECT * FROM animals", op)
    val = DbtPy.get_option(stmt, DbtPy.SQL_ATTR_CURSOR_TYPE, 0)
    print(val)

    op = {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_STATIC}
    stmt = DbtPy.exec_immediate(conn, "SELECT * FROM animals", op)
    val = DbtPy.get_option(stmt, DbtPy.SQL_ATTR_CURSOR_TYPE, 0)
    print(val)

#__END__
#__IDS_EXPECTED__
#0
#0
#0
#0
#



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_157_FetchAssocScrollableCursor_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_157)

  def run_test_157(self):
    conn = DbtPy.connect(config.ConnStr + 'ENABLESCROLLABLECURSORS=1', config.user, config.password)
    server = DbtPy.server_info( conn )

    if conn:
      sql = "SELECT id, name, breed, weight FROM animals ORDER BY breed"
      if (server.DBMS_NAME[0:3] != 'Inf'):
        result = DbtPy.exec_immediate(conn, sql, {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_KEYSET_DRIVEN})
      else:
        result = DbtPy.exec_immediate(conn, sql, {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_STATIC})

      i = 2
      row = DbtPy.fetch_assoc(result, i)
      while ( row ):
        if (server.DBMS_NAME[0:3] == 'Inf'):
	           print("%-5d %-16s %-32s %10s\n" % (row['id'], row['name'], row['breed'], row['weight']))
        else:
	           print("%-5d %-16s %-32s %10s\n" % (row['ID'], row['NAME'], row['BREED'], row['WEIGHT']))
        i = i + 2
        row = DbtPy.fetch_assoc(result, i)
#
#__END__
#__LUW_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00
#__ZOS_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00
#__SYSTEMI_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00
#__IDS_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_116_ConnActive(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_116)

  def run_test_116(self):
    conn = None
    is_alive = DbtPy.active(conn)
    if is_alive:
      print("Is active")
    else:
      print("Is not active")

    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    is_alive = DbtPy.active(conn)
    if is_alive:
      print("Is active")
    else:
      print("Is not active")

    DbtPy.close(conn)
    is_alive = DbtPy.active(conn)
    if is_alive:
      print("Is active")
    else:
      print("Is not active")

    # Executing active method multiple times to reproduce a customer reported defect
    print(DbtPy.active(conn))
    print(DbtPy.active(conn))
    print(DbtPy.active(conn))
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    print(DbtPy.active(conn))
    print(DbtPy.active(conn))
    print(DbtPy.active(conn))

#__END__
#__LUW_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__ZOS_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__SYSTEMI_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__IDS_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_014_KeysetDrivenCursorNegativeRow(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_014)

  def run_test_014(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    serverinfo = DbtPy.server_info( conn )

    query = 'SELECT * FROM animals ORDER BY name'

    if (serverinfo.DBMS_NAME[0:3] != 'Inf'):
      stmt = DbtPy.prepare(conn, query, {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_KEYSET_DRIVEN})
    else:
      stmt = DbtPy.prepare(conn, query)
    DbtPy.execute(stmt)
    data = DbtPy.fetch_both( stmt )
    while ( data ):
      print("%s : %s : %s : %s\n" % (data[0], data[1], data[2], data[3]))
      data = DbtPy.fetch_both( stmt )
    try:
      stmt = DbtPy.prepare(conn, query, {DbtPy.SQL_ATTR_CURSOR_TYPE:  DbtPy.SQL_CURSOR_KEYSET_DRIVEN})
      DbtPy.execute(stmt)
      rc = DbtPy.fetch_row(stmt, -1)
      print("Fetch row -1: %s" % str(rc))
    except:
      print("Requested row number must be a positive value")

    DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#1 : dog : Peaches          : 12.30
#0 : cat : Pook             : 3.20
#5 : goat : Rickety Ride     : 9.70
#2 : horse : Smarty           : 350.00
#6 : llama : Sweater          : 150.00
#Requested row number must be a positive value
#__ZOS_EXPECTED__
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#1 : dog : Peaches          : 12.30
#0 : cat : Pook             : 3.20
#5 : goat : Rickety Ride     : 9.70
#2 : horse : Smarty           : 350.00
#6 : llama : Sweater          : 150.00
#Requested row number must be a positive value
#__SYSTEMI_EXPECTED__
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#1 : dog : Peaches          : 12.30
#0 : cat : Pook             : 3.20
#5 : goat : Rickety Ride     : 9.70
#2 : horse : Smarty           : 350.00
#6 : llama : Sweater          : 150.00
#Requested row number must be a positive value
#__IDS_EXPECTED__
#3 : gold fish : Bubbles          : 0.10
#4 : budgerigar : Gizmo            : 0.20
#1 : dog : Peaches          : 12.30
#0 : cat : Pook             : 3.20
#5 : goat : Rickety Ride     : 9.70
#2 : horse : Smarty           : 350.00
#6 : llama : Sweater          : 150.00
#Requested row number must be a positive value



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_051_SetAutocommit_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_051)

  def run_test_051(self):
    options = { DbtPy.SQL_ATTR_AUTOCOMMIT:  DbtPy.SQL_AUTOCOMMIT_OFF }
      
    conn = DbtPy.connect(config.ConnStr, config.user, config.password, options)
      
    ac = DbtPy.autocommit(conn)
      
    print(ac)

#__END__
#__LUW_EXPECTED__
#0
#__ZOS_EXPECTED__
#0
#__SYSTEMI_EXPECTED__
#0
#__IDS_EXPECTED__
#0



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_250_FreeResult_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_250)

  def run_test_250(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from sales")
    result2 = DbtPy.exec_immediate(conn, "select * from staff")
    result3 = DbtPy.exec_immediate(conn, "select * from emp_photo")
    
    r1 = DbtPy.free_result(result)
    r2 = DbtPy.free_result(result2)
    r3 = DbtPy.free_result(result3)
    
    print(r1)
    print(r2)
    print(r3)

#__END__
#__LUW_EXPECTED__
#True
#True
#True
#__ZOS_EXPECTED__
#True
#True
#True
#__SYSTEMI_EXPECTED__
#True
#True
#True
#__IDS_EXPECTED__
#True
#True
#True



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_133_ExecuteLongInputParams(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_133)

  def run_test_133(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    if (not conn):
      print("Connection failed.")
      return 0

    DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)

    print("Starting test ...")
    res = ''
    sql =  "INSERT INTO animals (id, breed, name, weight) VALUES (?, ?, ?, ?)"
    try:
      stmt = DbtPy.prepare(conn, sql)
      res = DbtPy.execute(stmt,(128, 'hacker of human and technological nature', 'Wez the ruler of all things PECL', 88.3))
      
      stmt = DbtPy.prepare(conn, "SELECT breed, name FROM animals WHERE id = ?")
      res = DbtPy.execute(stmt, (128,))
      row = DbtPy.fetch_assoc(stmt)
      
      for i in row:
	         print(i)

      DbtPy.rollback(conn)
      print("Done")
    except:
      print("SQLSTATE: %s" % DbtPy.stmt_error(stmt))
      print("Message: %s" % DbtPy.stmt_errormsg(stmt))

    try:
        stmt = DbtPy.prepare(conn, "SELECT breed, name FROM animals WHERE id = ?")
        res = DbtPy.execute(stmt, (128,))
        row = DbtPy.fetch_assoc(stmt)
        if (row):
            for i in row:
                print(i)
        print(res)
        print("SQLSTATE: %s" % DbtPy.stmt_error(stmt))
        print("Message: %s" % DbtPy.stmt_errormsg(stmt))
    except:
        print("An Exception is not expected")
        print("SQLSTATE: %s" % DbtPy.stmt_error(stmt))
        print("Message: %s" % DbtPy.stmt_errormsg(stmt))

    DbtPy.rollback(conn)
    print("Done")

#__END__
#__IDS_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [GBasedbt][GBase ODBC Driver]String data right truncation. SQLCODE=-11023
#True
#SQLSTATE: 
#Message: 
#Done




import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_6792_FieldTypeRetStrDatetimeTimestamp(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_6792)

  def run_test_6792(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      drop = 'DROP TABLE table_6792'
      result = ''
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass

      t_val = '10:42:34'
      d_val = '1981-07-08'
      ts_val = '1981-07-08 10:42:34'
      ts_withT_val = '2013-06-06T15:30:39'
      
      server = DbtPy.server_info( conn )
      if (server.DBMS_NAME[0:3] == 'Inf'):
        statement = "CREATE TABLE table_6792 (col1 DATETIME HOUR TO SECOND, col2 DATE, col3 DATETIME YEAR TO SECOND, col4 DATETIME YEAR TO SECOND)"
        result = DbtPy.exec_immediate(conn, statement)
        statement = "INSERT INTO table_6792 (col1, col2, col3) values (?, ?, ?)"
        stmt = DbtPy.prepare(conn, statement)
        result = DbtPy.execute(stmt, (t_val, d_val, ts_val))
      else:
        statement = "CREATE TABLE table_6792 (col1 TIME, col2 DATE, col3 TIMESTAMP, col4 TIMESTAMP)"
        result = DbtPy.exec_immediate(conn, statement)
        statement = "INSERT INTO table_6792 (col1, col2, col3, col4) values (?, ?, ?, ?)"
        stmt = DbtPy.prepare(conn, statement)
        result = DbtPy.execute(stmt, (t_val, d_val, ts_val, ts_withT_val))

      statement = "SELECT * FROM table_6792"
      result = DbtPy.exec_immediate(conn, statement)
      
      for i in range(0, DbtPy.num_fields(result)):
        print(str(i) + ":" + DbtPy.field_type(result,i))

      statement = "SELECT * FROM table_6792"
      stmt = DbtPy.prepare(conn, statement)
      rc = DbtPy.execute(stmt)
      result = DbtPy.fetch_row(stmt)
      while ( result ):
        row0 = DbtPy.result(stmt, 0)
        row1 = DbtPy.result(stmt, 1)
        row2 = DbtPy.result(stmt, 2)
        row3 = DbtPy.result(stmt, 3)
        print(row0)
        print(row1)
        print(row2)
        print(row3)
        result = DbtPy.fetch_row(stmt)
      
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39
#__ZOS_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39
#__SYSTEMI_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39
#__IDS_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#None


# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_071_CloseSuccess(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_071)

  def run_test_071(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      rc = DbtPy.close(conn)
      if (rc == True):
        print("DbtPy.close succeeded")
      else:
        print("DbtPy.close FAILED\n")
    else:
      print("%s" % DbtPy.conn_errormsg())
      print(",sqlstate=%s" % DbtPy.conn_error())
      print("%s" % DbtPy.conn_errormsg())
      print("%s" % DbtPy.conn_errormsg())
      print("%s" % DbtPy.conn_errormsg())
      print("%s" % DbtPy.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#DbtPy.close succeeded
#__ZOS_EXPECTED__
#DbtPy.close succeeded
#__SYSTEMI_EXPECTED__
#DbtPy.close succeeded
#__IDS_EXPECTED__
#DbtPy.close succeeded



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_130_PrepExecuteSelectStmt(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_130)

  def run_test_130(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      stmt = DbtPy.prepare(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")
    
      if DbtPy.execute(stmt):
        row = DbtPy.fetch_tuple(stmt)
        while ( row ):
          for i in row:
            print(i)
            row = DbtPy.fetch_tuple(stmt)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_146_CallSPINAndOUTParams(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_146)

  def run_test_146(self):      
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )
    
    if conn:
      name = "Peaches"
      second_name = "Rickety Ride"
      weight = 0
    
      print("Values of bound parameters _before_ CALL:")
      print("  1: %s 2: %s 3: %d\n" % (name, second_name, weight))
     	
      stmt, name, second_name, weight = DbtPy.callproc(conn, 'match_animal', (name, second_name, weight))
    
      if stmt is not None:
        print("Values of bound parameters _after_ CALL:")
        print("  1: %s 2: %s 3: %d\n" % (name, second_name, weight))

#__END__
#__IDS_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_201_MultipleRsltsetsDiffColDefs(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_201)

  def run_test_201(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    serverinfo = DbtPy.server_info( conn )
    server = serverinfo.DBMS_NAME[0:3]
	
    procedure = """CREATE FUNCTION multiResults ()
       RETURNING CHAR(16), INT, VARCHAR(32), NUMERIC(7,2);
       
       DEFINE p_name CHAR(16);
       DEFINE p_id INT;
       DEFINE p_breed VARCHAR(32);
       DEFINE p_weight NUMERIC(7,2);
       
       FOREACH c1 FOR
    	  SELECT name, id, breed, weight
    	  INTO p_name, p_id, p_breed, p_weight
    	  FROM animals
    	  ORDER BY name DESC
    	  RETURN p_name, p_id, p_breed, p_weight WITH RESUME;
       END FOREACH;
    
    END FUNCTION;"""
    
    if conn:
        try:
            DbtPy.exec_immediate(conn, 'DROP PROCEDURE multiResults')
        except:
            pass
        DbtPy.exec_immediate(conn, procedure)
        stmt = DbtPy.exec_immediate(conn, 'CALL multiResults()')
    
        print("Fetching first result set")
        row = DbtPy.fetch_tuple(stmt)
        while ( row ):
           for i in row:
                print(str(i).strip())
           row = DbtPy.fetch_tuple(stmt)
       
        DbtPy.close(conn)
    else:
       print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#Fetching first result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_261_FetchObjectAccess(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_261)

  def run_test_261(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    server = DbtPy.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'Inf'):
      op = {DbtPy.ATTR_CASE: DbtPy.CASE_UPPER}
      DbtPy.set_option(conn, op, 1)

    if (server.DBMS_NAME[0:3] == 'Inf'):
      sql = "SELECT breed, TRIM(TRAILING FROM name) AS name FROM animals WHERE id = ?"
    else:
      sql = "SELECT breed, RTRIM(name) AS name FROM animals WHERE id = ?"

    if conn:
      stmt = DbtPy.prepare(conn, sql)
      DbtPy.execute(stmt, (0,))

#      NOTE: This is a workaround
#      function fetch_object() to be implemented...
#      pet = DbtPy.fetch_object(stmt)
#      while (pet):
#          print "Come here, %s, my little %s!" % (pet.NAME, pet.BREED)
#          pet = DbtPy.fetch_object(stmt)
      
      class Pet:
          pass
      
      data = DbtPy.fetch_assoc(stmt)
      while ( data ):
         pet = Pet()
         pet.NAME = data['NAME']
         pet.BREED = data['BREED']
         print("Come here, %s, my little %s!" % (pet.NAME, pet.BREED))
         data = DbtPy.fetch_assoc(stmt)
         
      DbtPy.close(conn)
      
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Come here, Pook, my little cat!
#__ZOS_EXPECTED__
#Come here, Pook, my little cat!
#__SYSTEMI_EXPECTED__
#Come here, Pook, my little cat!
#__IDS_EXPECTED__
#Come here, Pook, my little cat!



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_213_FieldDisplaySize_04(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_213)

  def run_test_213(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from sales")
    
    i = "sales_person"
    
    print("%s size %d\n" % (i, (DbtPy.field_display_size(result,i) or 0)))
    
    i = "REGION"
    
    print("%s size %d\n" % (i, (DbtPy.field_display_size(result,i) or 0)))
    
    i = "REgion"
    
    print("%s size %d\n" % (i, (DbtPy.field_display_size(result,i) or 0)))
    
    i = "HELMUT"
    
    print("%s size %d\n" % (i, (DbtPy.field_display_size(result,i) or 0)))
    
    t = DbtPy.field_display_size(result,"")
    
    print(t)
    
    t = DbtPy.field_display_size(result,"HELMUT")
    
    print(t)
    
    t = DbtPy.field_display_size(result,"Region")
    
    print(t)
    
    t = DbtPy.field_display_size(result,"SALES_DATE")
    
    print(t)

#__END__
#__LUW_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__ZOS_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__SYSTEMI_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__IDS_EXPECTED__
#sales_person size 15
#REGION size 0
#REgion size 0
#HELMUT size 0
#False
#False
#False
#False



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_062_Tables_03(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_062)

  def run_test_062(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    if conn:
      schema = 't'
      result = DbtPy.tables(conn,None,schema);    
      i = 0
      row = DbtPy.fetch_both(result)
      while ( row ):
        str = row[1] + "/" + row[2] + "/" + row[3]
        if (i < 4):
          print(str)
        i = i + 1
        row = DbtPy.fetch_both(result)

      DbtPy.exec_immediate(conn, 'DROP TABLE t.t1')
      DbtPy.exec_immediate(conn, 'DROP TABLE t.t2')
      DbtPy.exec_immediate(conn, 'DROP TABLE t.t3')
      DbtPy.exec_immediate(conn, 'DROP TABLE t.t4')

      print("done!")
    else:
      print("no connection: #{DbtPy.conn_errormsg}");    

#__END__
#__LUW_EXPECTED__
#T/T1/TABLE
#T/T2/TABLE
#T/T3/TABLE
#T/T4/TABLE
#done!
#__ZOS_EXPECTED__
#T/T1/TABLE
#T/T2/TABLE
#T/T3/TABLE
#T/T4/TABLE
#done!
#__SYSTEMI_EXPECTED__
#T/T1/TABLE
#T/T2/TABLE
#T/T3/TABLE
#T/T4/TABLE
#done!
#__IDS_EXPECTED__
#t/t1/TABLE
#t/t2/TABLE
#t/t3/TABLE
#t/t4/TABLE
#done!



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_230_FieldTypePos(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_230)

  def run_test_230(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    result = DbtPy.exec_immediate(conn, "select * from sales")
    result2 = DbtPy.exec_immediate(conn, "select * from staff")
    result3 = DbtPy.exec_immediate(conn, "select * from emp_photo")
    
    for i in range(0, DbtPy.num_fields(result) + 1):
      print(str(i) + ":" + str(DbtPy.field_type(result,i)))
    
    print("\n-----")
    
    for i in range(0, DbtPy.num_fields(result2)):
      print(str(i) + ":" + str(DbtPy.field_type(result2,i)))
      
    print("\n-----")

    for i in range(0, 3):
      print(str(i) + ":" + str(DbtPy.field_type(result3,i)))

    print("\n-----")
    
    print("region:%s" % str(DbtPy.field_type(result,'region')))
    print("5:%s" % str(DbtPy.field_type(result2,5)))

#__END__
#__LUW_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:False
#5:decimal
#__ZOS_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:False
#5:decimal
#__SYSTEMI_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:False
#5:decimal
#__IDS_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:string
#
#-----
#region:string
#5:decimal




import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_265_NoAffectedRows(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_265)

  def run_test_265(self):
    # Make a connection
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    cursor_option = {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_STATIC}

    if conn:
      server = DbtPy.server_info( conn )
      if (server.DBMS_NAME[0:3] == 'Inf'):
         op = {DbtPy.ATTR_CASE: DbtPy.CASE_UPPER}
         DbtPy.set_option(conn, op, 1)

      try:
        sql = 'drop table test'

        stmt = DbtPy.prepare(conn, sql)
        DbtPy.set_option(stmt, cursor_option, 0)
        DbtPy.execute(stmt)
        print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))
      except:
        pass

      if ((server.DBMS_NAME[0:3] == 'Inf') or (server.DBMS_NAME[0:2] == "AS")):
        sql = "create table test(id integer, name VARCHAR(10), text_col VARCHAR(100), some_var VARCHAR(100) )"
      else:
        sql = "create table test(id integer, name VARCHAR(10), text_col CLOB, some_var XML )"

      stmt = DbtPy.prepare(conn, sql)
      DbtPy.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))

      sql = 'select id from test'

      stmt = DbtPy.prepare(conn, sql)
      #DbtPy.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))

      sql = "insert into test values( 1, 'some', 'here is a clob value', '<?xml version=\"1.0\" encoding=\"UTF-8\" ?><test attribute=\"value\"/>')"

      stmt = DbtPy.prepare(conn, sql)
      #DbtPy.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))

      sql = "insert into test values(2, 'value', 'clob data', NULL)"

      stmt = DbtPy.prepare(conn, sql)
      #DbtPy.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))

      sql = "insert into test values(2, 'in varchar', 'data2', NULL)"

      stmt = DbtPy.prepare(conn, sql)
      #DbtPy.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))

      sql = 'select * from test'

      stmt = DbtPy.prepare(conn, sql)
      #DbtPy.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))
      row = DbtPy.fetch_tuple(stmt)
      while ( row ):
        print("%s, %s, %s, %s\n" %(row[0], row[1], row[2], ((row[3] is not None) and row[3].startswith('\ufeff')) and  row[3][1:] or  row[3]))
        row = DbtPy.fetch_tuple(stmt)

      sql = 'select id, name from test where id = ?'

      stmt = DbtPy.prepare(conn, sql)
      #fx_db.set_option(stmt, cursor_option, 0)
      DbtPy.execute(stmt, (2,))
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))
      row = DbtPy.fetch_tuple(stmt)
      while ( row ):
        print("%s, %s\n" %(row[0], row[1]))
        row = DbtPy.fetch_tuple(stmt)

      if (server.DBMS_NAME[0:3] == 'Inf'):
        sql = "select * from test"
      else:
        sql = 'select * from test fetch first 12 rows only optimize for 12 rows'

      stmt = DbtPy.prepare(conn, sql)
      #DbtPy.set_option(stmt, cursor_option, 0)
      #DbtPy.num_fields(stmt)
      DbtPy.execute(stmt)
      print("Number of affected rows: %d" % DbtPy.get_num_result(stmt))
      row = DbtPy.fetch_tuple(stmt)
      while ( row ):
        print("%s, %s, %s, %s\n" %(row[0], row[1], row[2], ((row[3] is not None) and row[3].startswith('\ufeff')) and  row[3][1:] or  row[3]))
        row = DbtPy.fetch_tuple(stmt)

      DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: 0
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: -1
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#__ZOS_EXPECTED__
#Number of affected rows: -2
#Number of affected rows: -2
#Number of affected rows: 0
#Number of affected rows: -2
#Number of affected rows: -1
#Number of affected rows: -2
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#__SYSTEMI_EXPECTED__
#Number of affected rows: -2
#Number of affected rows: -2
#Number of affected rows: 0
#Number of affected rows: -2
#Number of affected rows: -1
#Number of affected rows: -2
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#__IDS_EXPECTED__
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None



# 

#

#

import unittest, sys
import DbtPy
import config
import os
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_122_FieldNameDiffCaseColNames(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_122)

  def run_test_122(self):
    os.environ['DELIMIDENT'] = 'y' 
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    if conn:
      drop = "drop table ftest"
      try:
        DbtPy.exec_immediate( conn, drop )
      except:
        pass
      
      create = "create table ftest ( \"TEST\" integer, \"test\" integer, \"Test\" integer  )"
      DbtPy.exec_immediate(conn, create)
      
      insert = "INSERT INTO ftest values (1,2,3)"
      DbtPy.exec_immediate(conn, insert)
      
      stmt = DbtPy.exec_immediate(conn, "SELECT * FROM ftest")
    
      num1 = DbtPy.field_name(stmt, 0)
      num2 = DbtPy.field_name(stmt, 1)
      num3 = DbtPy.field_name(stmt, 2)
      
      num4 = DbtPy.field_name(stmt, "TEST")
      num5 = DbtPy.field_name(stmt, 'test')
      num6 = DbtPy.field_name(stmt, 'Test')

      print("string(%d) \"%s\"" % (len(num1), num1))
      print("string(%d) \"%s\"" % (len(num2), num2))
      print("string(%d) \"%s\"" % (len(num3), num3))

      print("string(%d) \"%s\"" % (len(num4), num4))
      print("string(%d) \"%s\"" % (len(num5), num5))
      print("string(%d) \"%s\"" % (len(num6), num6))
      
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__ZOS_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__SYSTEMI_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__IDS_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_031_ResultIndexPosition(self):
     obj = DbtPyTestFunctions()
     obj.assert_expect(self.run_test_031)

  def run_test_031(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      
    if conn:
      stmt = DbtPy.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")
        
      while (DbtPy.fetch_row(stmt)):
        id = DbtPy.result(stmt, 0)
        print("int(%d)" % id)
        breed = DbtPy.result(stmt, 1)
        print("string(%d) \"%s\"" % (len(breed), breed))
        name = DbtPy.result(stmt, 2)
        print("string(%d) \"%s\"" % (len(name), name))
        weight = DbtPy.result(stmt, 3)
        print("string(%d) \"%s\"" % (len(str(weight)), weight))
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"
#__ZOS_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"
#__SYSTEMI_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"
#__IDS_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_063_Tables_04(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_063)

  def run_test_063(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      
    result = DbtPy.tables(conn, None, "SYSIBM", "", "VIEW")
    
    if (type(result) == DbtPy.IFXStatement):
      print("Resource is a IFX Statement")
      
    DbtPy.free_result(result)

#__END__
#__IDS_EXPECTED__
#Resource is a IFX Statement



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_101_InsertDeleteFieldCount(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_101)

  def run_test_101(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    if conn:
      result = DbtPy.exec_immediate(conn,"insert into t_string values(123,1.222333,'one to one')")
      if result:
        cols = DbtPy.num_fields(result)
        print("col: %d" % cols)
        rows = DbtPy.num_rows(result)
        print("affected row: %d" % rows)
      result = DbtPy.exec_immediate(conn,"delete from t_string where a=123")
      if result:
        cols = DbtPy.num_fields(result)
        print("col: %d" % cols)
        rows = DbtPy.num_rows(result)
        print("affected row: %d" % rows)
    else:
      print("no connection");    

#__END__
#__LUW_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1
#__ZOS_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1
#__SYSTEMI_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1
#__IDS_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1



#

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_048_FetchTupleBinaryData_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_048)

  def run_test_048(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    if (not conn):
      print("Could not make a connection.") 
      return 0
    server = DbtPy.server_info( conn )
    
    fp = open("tests/spook_out.png", "wb")
    result = DbtPy.exec_immediate(conn, "SELECT picture FROM animal_pics WHERE name = 'Spook'")
    if (not result):
      print("Could not execute SELECT statement.")
      return 0
    row = DbtPy.fetch_tuple(result)
    if row:
      fp.write(row[0])
    else:
      print(DbtPy.stmt_errormsg())
    fp.close()
    cmp = (open('tests/spook_out.png', "rb").read() == open('tests/spook.png', "rb").read())
    print("Are the files the same:", cmp)

#__END__
#__LUW_EXPECTED__
#Are the files the same: True
#__ZOS_EXPECTED__
#Are the files the same: True
#__SYSTEMI_EXPECTED__
#Are the files the same: True
#__IDS_EXPECTED__
#Are the files the same: True



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_005_ConnBadUserBadPwd(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_005)

  def run_test_005(self):
    baduser = "non_user"
    badpass = "invalid_password"
    dsn = "DATABASE=" + config.ConnStr + ";UID=" + baduser + ";PWD=" + badpass + ";"
    try:
      conn = DbtPy.connect(dsn, "", "")
      print("odd, DbtPy.connect succeeded with an invalid user / password")
      DbtPy.close(conn)
    except: 
      print("Ooops")

#__END__
#__LUW_EXPECTED__
#Ooops
#__ZOS_EXPECTED__
#Ooops
#__SYSTEMI_EXPECTED__
#Ooops
#__IDS_EXPECTED__
#Ooops



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):
  
  def test_006_ConnPassingOpts(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_006)
	  
  def run_test_006(self):    

    options1 = {DbtPy.SQL_ATTR_CURSOR_TYPE:  DbtPy.SQL_CURSOR_KEYSET_DRIVEN}
    options2 = {DbtPy.SQL_ATTR_CURSOR_TYPE: DbtPy.SQL_CURSOR_FORWARD_ONLY}
      
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
  
    if conn:
      serverinfo = DbtPy.server_info( conn )

      if (serverinfo.DBMS_NAME[0:3] == 'Inf'):
        options1 = options2

      stmt = DbtPy.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0", options2)
      DbtPy.execute(stmt)
      data = DbtPy.fetch_both(stmt)
      while ( data ):
        print(data[0])
        data = DbtPy.fetch_both(stmt)
      
      print("")

      stmt = DbtPy.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0", options1)
      DbtPy.execute(stmt)
      data = DbtPy.fetch_both(stmt)
      while ( data ):
        print(data[0])
        data = DbtPy.fetch_both(stmt)
    
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    



# 

#

#
# NOTE: IDS requires that you pass the schema name (cannot pass nil)
#
# NOTE: IDS will not return any rows from column_privileges unless
#       there have been privileges granted to another user other
#       then the user that is running the script.  This test assumes
#       that no other user has been granted permission and therefore
#       will return no rows.

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):
  
  def test_023_ColumnPrivileges(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_023)

  def run_test_023(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    if (conn != 0):
      stmt = DbtPy.column_privileges(conn, None, config.user, 'animals')
      row = DbtPy.fetch_tuple(stmt)
      if row:
        print(row[0])
        print(row[1])
        print(row[2])
        print(row[3])
        print(row[4])
        print(row[5])
        print(row[6])
        print(row[7])
      DbtPy.close(conn)
    else:
      print(DbtPy.conn_errormsg())
      print("Connection failed\n\n")

#__END__
#__IDS_EXPECTED__
#stores7
#gbasedbt
#animals
#breed
#gbasedbt
#public
#INSERT
#NO



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_111_FieldNumAddCol(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_111)

  def run_test_111(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )
    if conn:
      DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)

      insert = "INSERT INTO animals values (7, 'cat', 'Benji', 5.1)"
      DbtPy.exec_immediate(conn, insert)
      
      stmt = DbtPy.exec_immediate(conn, "SELECT breed, COUNT(breed) AS number FROM animals GROUP BY breed ORDER BY breed")
    
      if (server.DBMS_NAME[0:3] == 'Inf'):
        num1 = DbtPy.field_num(stmt, "id")
        num2 = DbtPy.field_num(stmt, "breed")
        num3 = DbtPy.field_num(stmt, "number")
        num4 = DbtPy.field_num(stmt, "NUMBER")
        num5 = DbtPy.field_num(stmt, "bREED")
        num6 = DbtPy.field_num(stmt, 8)
        num7 = DbtPy.field_num(stmt, 1)
        num8 = DbtPy.field_num(stmt, "WEIGHT")
      else:
        num1 = DbtPy.field_num(stmt, "ID")
        num2 = DbtPy.field_num(stmt, "BREED")
        num3 = DbtPy.field_num(stmt, "NUMBER")
        num4 = DbtPy.field_num(stmt, "number")
        num5 = DbtPy.field_num(stmt, "Breed")
        num6 = DbtPy.field_num(stmt, 8)
        num7 = DbtPy.field_num(stmt, 1)
        num8 = DbtPy.field_num(stmt, "weight")
  
      print("%s" % num1)
      print("int(%d)" % num2)
      print("int(%d)" % num3)
      print("%s" % num4)
      
      print("%s" % num5)
      print("%s" % num6)
      print("int(%d)" % num7)
      print("%s" % num8)

      DbtPy.rollback(conn)
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#False
#int(0)
#int(1)
#False
#False
#False
#int(1)
#False
